Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3360)

Unified Diff: chrome/browser/sync/test/integration/two_client_preferences_sync_test.cc

Issue 301343002: mac: Clean up autofill integration with Address Book. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@autofill_cleanup2_base
Patch Set: Fix a cross-platform problem. Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/test/integration/two_client_preferences_sync_test.cc
diff --git a/chrome/browser/sync/test/integration/two_client_preferences_sync_test.cc b/chrome/browser/sync/test/integration/two_client_preferences_sync_test.cc
index a16191c80a46e0d96072085a57fe464ffe4a7d44..d24041b7e3cc34f463413b9a0e94ed6c2d0a38ba 100644
--- a/chrome/browser/sync/test/integration/two_client_preferences_sync_test.cc
+++ b/chrome/browser/sync/test/integration/two_client_preferences_sync_test.cc
@@ -380,24 +380,25 @@ IN_PROC_BROWSER_TEST_F(TwoClientPreferencesSyncTest,
// TCM ID - 3624302.
IN_PROC_BROWSER_TEST_F(TwoClientPreferencesSyncTest,
- kAutofillAuxiliaryProfilesEnabled) {
+ kAutofillAndroidAuxiliaryProfilesEnabled) {
ASSERT_TRUE(SetupSync()) << "SetupSync() failed.";
DisableVerifier();
- ASSERT_TRUE(
- BooleanPrefMatches(autofill::prefs::kAutofillAuxiliaryProfilesEnabled));
+ ASSERT_TRUE(BooleanPrefMatches(
+ autofill::prefs::kAutofillAndroidAuxiliaryProfilesEnabled));
- ChangeBooleanPref(0, autofill::prefs::kAutofillAuxiliaryProfilesEnabled);
+ ChangeBooleanPref(0,
+ autofill::prefs::kAutofillAndroidAuxiliaryProfilesEnabled);
ASSERT_TRUE(GetClient(0)->AwaitMutualSyncCycleCompletion(GetClient(1)));
- // kAutofillAuxiliaryProfilesEnabled is only synced on Mac.
-#if defined(OS_MACOSX)
- ASSERT_TRUE(
- BooleanPrefMatches(autofill::prefs::kAutofillAuxiliaryProfilesEnabled));
+ // kAutofillAndroidAuxiliaryProfilesEnabled is only synced on Android.
+#if defined(OS_ANDROID)
+ ASSERT_TRUE(BooleanPrefMatches(
+ autofill::prefs::kAutofillAndroidAuxiliaryProfilesEnabled));
#else
- ASSERT_FALSE(
- BooleanPrefMatches(autofill::prefs::kAutofillAuxiliaryProfilesEnabled));
-#endif // OS_MACOSX
+ ASSERT_FALSE(BooleanPrefMatches(
+ autofill::prefs::kAutofillAndroidAuxiliaryProfilesEnabled));
+#endif // OS_ANDROID
}
// TCM ID - 3717298.

Powered by Google App Engine
This is Rietveld 408576698